@@ -1,4 +1,19 @@
 # -*- coding: utf-8 -*-
+# <markment - markdown-based documentation generator for python>
+# Copyright (C) <2013>  Gabriel Falcão <gabriel@nacaolivre.org>
+#
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 from __future__ import unicode_literals
 
 
@@ -219,10 +234,10 @@ class Node(object):
         instance.
 
         ```python
-        way_back = Node('/foo/bar').depth_of('/foo/bar/another/dir/file.py')
+        way_back = Node('/foo/bar').path_to_related('/foo/bar/another/dir/file.py')
         assert way_back == '../../'
 
-        way_back = Node('/foo/bar/docs/static/file.css').depth_of('/foo/bar/docs/intro/index.md')
+        way_back = Node('/foo/bar/docs/static/file.css').path_to_related('/foo/bar/docs/intro/index.md')
         assert way_back == '../static/file.css'
         ```
         """
@@ -346,17 +361,11 @@ class Generator(object):
 
         link, levels = self.get_levels(link)
         in_theme = self.theme.node.find(link)
-        in_local = self.project.node.find(link)
 
         if levels:
             prefix = link
 
-        if in_local:
-            found = in_local
-            found_base = self.project.node.dir
-            link = found_base.relative(found.path)
-
-        elif in_theme:
+        if in_theme:
             found = in_theme
             found_base = self.theme.node.dir
             found_relative = found_base.relative(found.path)
